@@ -4,7 +4,7 @@ test_that("The output is right for a given input", {
   test_df <- data.frame('CellMaterial' = 'mono-silicon',
                         'EncapsulantMaterial' = 'EVA')
 
-  output <- jsonlite::fromJSON(fairify_data(test_df, domain = 'PVModule')[[1]])
+  output <- jsonlite::fromJSON(fairify_data(test_df, domain = 'photovoltaicModule')[[1]])
 
   expect_identical(output$ProdModule$ProdCell$CellMaterial$value, 'mono-silicon')
   expect_identical(output$ProdModule$ProdEncapsulant$EncapsulantMaterial$value, 'EVA')
